==> dabstick-radio-0.92.tgz: dabstick-radio-0.92/input/dabstick.h <==
#
/*
 *
 *    Copyright (C) 2010, 2011, 2012, 2013
 *    Jan van Katwijk (J.vanKatwijk@gmail.com)
 *    JFF Consultancy
 *
 *    This file is part of the JFF SDR (JSDR).
 *    Many of the ideas as implemented in JSDR are derived from
 *    other work, made available through the GNU general Public License. 
 *    All copyrights of the original authors are recognized.
 *
 *    JSDR is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    JSDR is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with JSDR; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef _DABSTICK
#define	_DABSTICK

#include	<stdlib.h>
#include	<stdio.h>
#include	<math.h>
#include	<string.h>
#include	<unistd.h>
#include	<stdint.h>
#include	<QObject>
#include	"jff-include.h"
#include	"ringbuffer.h"
#include	"fir-filters.h"
#include	"virtual_input.h"

class	Driver;
//
//	This class is a simple wrapper around the linked
//	rtlsdr library.
//	It does not do any processing
class	dabstick: public virtualInput {
public:
			dabstick	(int32_t, bool *);
			~dabstick	(void);
	void		setVFOFrequency	(int32_t);
	void		getVFOFrequency	(int32_t *);
	int32_t		setExternalRate	(int32_t);
	int32_t		setExternalGain	(int32_t);
	uint8_t		myIdentity	(void);
//	interface to the reader
	bool		restartReader	(void);
	void		stopReader	(void);
	int32_t		getSamples	(uint8_t *, int32_t);
	int32_t		getSamples	(uint8_t *, int32_t, int32_t);
	int32_t		Samples		(void);
	void		freqCorrection	(int32_t);
	int32_t		getSamplesMissed	(void);
//
//	These need to be visible for the separate usb handling thread
	RingBuffer<uint8_t>	*_I_Buffer;
	struct rtlsdr_dev	*device;
	int32_t		sampleCounter;
private:
	int32_t		rateIn;
	int32_t		deviceCount;
	Driver		*workerHandle;
	int32_t		lastFrequency;
	int32_t		decimatingScale;
	bool		open;
};
#endif

==> dabstick-radio-0.95.tgz: dabstick-radio-0.95/input/dabstick.h <==
#
/*
 *
 *    Copyright (C) 2010, 2011, 2012, 2013
 *    Jan van Katwijk (J.vanKatwijk@gmail.com)
 *    JFF Consultancy
 *
 *    This file is part of the JFF SDR (JSDR).
 *    Many of the ideas as implemented in JSDR are derived from
 *    other work, made available through the GNU general Public License. 
 *    All copyrights of the original authors are recognized.
 *
 *    JSDR is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    JSDR is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with JSDR; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef _DABSTICK
#define	_DABSTICK

#include	<stdlib.h>
#include	<stdio.h>
#include	<math.h>
#include	<string.h>
#include	<unistd.h>
#include	<stdint.h>
#include	<QObject>
#include	"jff-include.h"
#include	"ringbuffer.h"
#include	"fir-filters.h"
#include	"virtual_input.h"

class	Driver;
//
//	This class is a simple wrapper around the linked
//	rtlsdr library.
//	It does not do any processing
class	dabstick: public virtualInput {
public:
			dabstick	(int32_t, int32_t, int32_t, bool *);
			~dabstick	(void);
	void		setVFOFrequency	(int32_t);
	void		getVFOFrequency	(int32_t *);
	int32_t		setExternalRate	(int32_t);
	int32_t		setExternalGain	(int32_t);
	uint8_t		myIdentity	(void);
//	interface to the reader
	bool		restartReader	(void);
	void		stopReader	(void);
	int32_t		getSamples	(uint8_t *, int32_t);
	int32_t		getSamples	(uint8_t *, int32_t, int32_t);
	int32_t		Samples		(void);
	void		freqCorrection	(int32_t);
	int32_t		getSamplesMissed	(void);
	void		resetBuffer	(void);
//
//	These need to be visible for the separate usb handling thread
	RingBuffer<uint8_t>	*_I_Buffer;
	struct rtlsdr_dev	*device;
	int32_t		sampleCounter;
	int32_t		bufferLength;
private:
	int32_t		rateIn;
	int32_t		deviceCount;
	Driver		*workerHandle;
	int32_t		lastFrequency;
	int32_t		decimatingScale;
	bool		open;
};
#endif
